# Custom version of lpeg for Rosie Pattern Language

See [Rosie Pattern Language](https://github.com/jamiejennings/rosie-pattern-language).

The original lpeg implementation is [here](http://www.inf.puc-rio.br/~roberto/lpeg).
